
/////////////////////////////////////////////////////////////////////////////////////////////////
//
//  Licensed Materials - Property of IBM
//  Restricted Material of IBM
//  IBM Rational Test RealTime
//  (c) Copyright IBM Corp. 2003-2007 All Rights Reserved.
//
//  US Governement Users Restricted Rights - Use, duplication or
//  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//
/////////////////////////////////////////////////////////////////////////////////////////////////

// Product version: 7.0.5.1

/////////////////////////////////////////////////////////////////////// 
//JUnit is a regression testing framework written by Erich           // 
//Gamma and Kent Beck. It is used by the developer who               // 
//implements unit tests in Java.                                     // 
//JUnit is Open Source http://www.opensource.org/ Software,          // 
//released under the IBM's Common Public License Version 0.5         // 
//http://oss.software.ibm.com/developerworks/oss/license-cpl.htm     // 
//l and hosted on SourceForge http://sourceforge.net/projects/junit/.// 
/////////////////////////////////////////////////////////////////////// 

package j2meunit.framework;

import java.util.*;

/**
 * A <code>TestResult</code> collects the results of executing
 * a test case. It is an instance of the Collecting Parameter pattern.
 * The test framework distinguishes between <i>failures</i> and <i>errors</i>.
 * A failure is anticipated and checked for with assertions. Errors are
 * unanticipated problems like an <code>ArrayIndexOutOfBoundsException</code>.
 *
 * @see Test
 */
public final class TestResult implements VerifyListener{
    protected Vector fFailures;
    protected Vector fErrors;
    protected Vector fListeners;
    protected int fRunTests, fAssertions;
    protected Vector fVerifyListener;
    protected int fVerifywrong;

    private boolean fStop;
/**
 *
 */
public TestResult() {
    fFailures = new Vector();
    fErrors = new Vector();
    fListeners = new Vector();

    fVerifyListener = new Vector();
    fVerifywrong = 0;

    fRunTests = 0;
    fStop = false;
}
/**
 * Adds an error to the list of errors. The passed in exception
 * caused the error.
 */
public void addError(Test test, Throwable t) {
    fErrors.addElement(new TestFailure(test, t));
    for (Enumeration e = cloneListeners().elements(); e.hasMoreElements();) {
	((TestListener) e.nextElement()).addError(test, t);
    }
}
/**
 * Adds a failure to the list of failures. The passed in exception
 * caused the failure.
 */
public synchronized void addFailure(Test test, AssertionFailedError t) {
    fFailures.addElement(new TestFailure(test, t));
    for (Enumeration e = cloneListeners().elements(); e.hasMoreElements();) {
	((TestListener) e.nextElement()).addFailure(test, t);
    }
}
/**
 * Registers a VerifyFailure
 */
public synchronized void addVerifyFailure(Test test)
    {
	fVerifywrong++;
	for (Enumeration e= cloneVerifyListeners().elements(); e.hasMoreElements(); ) {
	    ((VerifyListener)e.nextElement()).addVerifyFailure(test);
	}
    }
/**
 * Get verify errors.
 */
public synchronized int verifyCount() {
    return fVerifywrong;
}
/**
 * Registers a VerifyListener
 */
public synchronized void addVerifyListener(VerifyListener listener) {
    fVerifyListener.addElement(listener);
}
/**
 * Registers a TestListener
 */
public synchronized void addListener(TestListener listener) {
	fListeners.addElement(listener);
}
/**
 * Gets the number of detected failures.
 */
public synchronized int assertionCount() {
	return fAssertions;
}
/**
 * Adds a failure to the list of failures. The passed in exception
 * caused the failure.
 */
public synchronized void assertionMade() {
    fAssertions++;
}
/**
 * Returns a copy of the listeners.
 */
private synchronized Vector cloneVerifyListeners() {
    Vector cloneListeners = new Vector();
    Enumeration iterator = fVerifyListener.elements();
    while (iterator.hasMoreElements())
	cloneListeners.addElement(iterator.nextElement());
    return cloneListeners;
}
/**
 *
 */
private synchronized Vector cloneListeners() {
    Vector cloneListeners = new Vector();
    Enumeration iterator = fListeners.elements();
    while (iterator.hasMoreElements())
	cloneListeners.addElement(iterator.nextElement());
    return cloneListeners;
}
/**
 * Informs the result that a test was completed.
 */
public void endTest(Test test) {
	for (Enumeration e = cloneListeners().elements(); e.hasMoreElements();) {
		((TestListener) e.nextElement()).endTest(test);
	}
}
/**
 * Gets the number of detected errors.
 */
public synchronized int errorCount() {
	return fErrors.size();
}
/**
 * Returns an Enumeration for the errors
 */
public synchronized Enumeration errors() {
	return fErrors.elements();
}
/**
 * Gets the number of detected failures.
 */
public synchronized int failureCount() {
	return fFailures.size();
}
/**
 * Returns an Enumeration for the failures
 */
public synchronized Enumeration failures() {
	return fFailures.elements();
}
/**
 * Runs a TestCase.
 */
protected void run(final TestCase test) {
    startTest(test);
    Protectable p = new Protectable() {
	    public void protect() throws Throwable {
		test.runBare();
	    }
	};
    runProtected(test, p);
    endTest(test);
}
/**
 * Gets the number of run tests.
 */
public synchronized int runCount() {
	return fRunTests;
}
/**
 * Runs a TestCase.
 */
public void runProtected(final Test test, Protectable p) {
    try {
	p.protect();
    }
    catch (AssertionFailedError e) {
	addFailure(test, e);
    }
    catch (Throwable e) {
	addError(test, e);
    }
}
/**
 * Gets the number of run tests.
 * @deprecated use <code>runCount</code> instead
 */
public synchronized int runTests() {
	return runCount();
}
/**
 * Verifys whether the test run should stop
 */
public synchronized boolean shouldStop() {
	return fStop;
}
/**
 * Informs the result that a test will be started.
 */
public void startTest(Test test) {
    synchronized (this) {
	fRunTests++;
    }
    for (Enumeration e = cloneListeners().elements(); e.hasMoreElements();) {
	((TestListener) e.nextElement()).startTest(test);
    }
}
/**
 * Marks that the test run should stop.
 */
public synchronized void stop() {
	fStop = true;
}
/**
 * Gets the number of detected errors.
 * @deprecated use <code>errorCount</code> instead
 */
public synchronized int testErrors() {
	return errorCount();
}
/**
 * Gets the number of detected failures.
 * @deprecated use <code>failureCount</code> instead
 */
public synchronized int testFailures() {
	return failureCount();
}
/**
 * Returns whether the entire test was successful or not.
 */
public synchronized boolean wasSuccessful() {
    return testFailures() == 0 && testErrors() == 0 && verifyCount() == 0;
}
}

































